#ifndef POPUPHPP
#define POPUPHPP

#include <string.h>

#include "box.hpp"
#include "screen.hpp"
#include "graphics.hpp"
#include "limit.hpp"
#include "legend.hpp"
#include "database.hpp"

#define POPUP_BUTTON_WIDTH 70
#define POPUP_BUTTON_HEIGHT 38

class PopupWindowButton : public Icon {

	friend class PopupWindow;
	friend class PopupWindowExitButton;

	ShadedBox* box;
	PopupWindow* window;
	void (*open_window)(PopupWindowButton*);
	char *text1;
	char *text2;
	COLOR_TYPE text_color;
	COLOR_TYPE shade_color;
	COLOR_TYPE border_color;
	COLOR_TYPE fill_color;
	COLOR_TYPE inactive_color;
	COLOR_TYPE active_color;

public:

	PopupWindowButton(void (*)(PopupWindowButton*),
			  int, int, int, int, char*, char*);
	void Display();
	int WindowOpened() { return window ? 1 : 0; }
	void Highlight();
	void UnHighlight();
	void LeftButtonPressed();
	void LeftButtonReleased();
	virtual ~PopupWindowButton();
};


#define POPUP_WINDOW_LEGEND_HEIGHT 20

class PopupWindow : public Icon {

	  friend class PopupWindowButton;
	  friend class PopupWindowExitButton;

	  ShadedBox* box;
	  PopupWindowButton* parent_button;
	  PopupWindowExitButton* exit_button;

	  COLOR_TYPE shade_color;
	  COLOR_TYPE border_color;
	  COLOR_TYPE inactive_color;
	  COLOR_TYPE active_color;
	  COLOR_TYPE title_color;
	  COLOR_TYPE title_backdrop_color;

public:

	PopupWindow(PopupWindowButton*, int, int,
		    int, int, char*);
	virtual void Display();
	virtual ~PopupWindow();
};


class PopupWindowExitButton: public Icon {

	friend class TitleBox;
	PopupWindow* parent_window;
	TopShadedBox* top_box;
	char legend [MAX_LEGEND_LENGTH + 1];

	COLOR_TYPE inactive_color;
	COLOR_TYPE active_color;
	COLOR_TYPE legend_color;
	COLOR_TYPE shade_color;
	COLOR_TYPE border_color;
	COLOR_TYPE fill_color;

public:

	PopupWindowExitButton(PopupWindow*, char*,
		   COLOR_TYPE,
		   COLOR_TYPE,
		   COLOR_TYPE,
		   COLOR_TYPE,
		   COLOR_TYPE,
		   int, int, int, int);
	void Display();
	void LeftButtonPressed();
	void LeftButtonReleased();
	virtual ~PopupWindowExitButton();
};

#endif
